[![PyPI version](https://img.shields.io/pypi/v/emipy.svg)](https://pypi.org/project/emipy/)
[![Documentation build status](https://img.shields.io/readthedocs/emipy.svg)](https://readthedocs.org/projects/emipy/builds/)
![Python version](https://img.shields.io/pypi/pyversions/emipy.svg)
![LICENSE](https://img.shields.io/pypi/l/emipy.svg)

# About
emipy is a package for processing data of pollutant releases and pollutant transfers.
It's main target is to enable a fast output of individual data set requests and to provide visualisation options.

The data are provided by the [European Environment Agency](https://www.eea.europa.eu/data-and-maps/data/member-states-reporting-art-7-under-the-european-pollutant-release-and-transfer-register-e-prtr-regulation-23).

# Documentation
For the documentation take a look over [here](https://emipy.readthedocs.io/en/latest/).


